==> connectagram_1.2.11.orig.tar.gz: connectagram-1.2.11/translations/connectagram_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>ChainPattern</name>
    <message>
        <location filename="../src/pattern.h" line="145"/>
        <source>Chain</source>
        <translation>Catena</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <location filename="../src/clock.cpp" line="70"/>
        <source>Loading</source>
        <translation>Caricamento in corso</translation>
    </message>
    <message>
        <location filename="../src/clock.cpp" line="112"/>
        <source>Paused</source>
        <translation>Pausa</translation>
    </message>
</context>
<context>
    <name>Definitions</name>
    <message>
        <location filename="../src/definitions.cpp" line="36"/>
        <source>Definitions</source>
        <translation>Definizioni</translation>
    </message>
    <message>
        <location filename="../src/definitions.cpp" line="145"/>
        <source>Downloading definition...</source>
        <translation>Scaricamento definizione in corso...</translation>
    </message>
    <message>
        <location filename="../src/definitions.cpp" line="153"/>
        <source>Unsolved word</source>
        <translation>Parola irrisolta</translation>
    </message>
</context>
<context>
    <name>Dictionary</name>
    <message>
        <location filename="../src/dictionary.cpp" line="135"/>
        <source>Definition from Wiktionary, the free dictionary</source>
        <translation>Definizione da Wikizionario, il dizionario gratuito</translation>
    </message>
    <message>
        <location filename="../src/dictionary.cpp" line="142"/>
        <source>No definition found</source>
        <translation>Nessuna definizione trovata</translation>
    </message>
    <message>
        <location filename="../src/dictionary.cpp" line="145"/>
        <source>Unable to connect to Wiktionary</source>
        <translation>Impossibile connettersi a Wikizionario</translation>
    </message>
</context>
<context>
    <name>FencePattern</name>
    <message>
        <location filename="../src/pattern.h" line="170"/>
        <source>Fence</source>
        <translation>Recinto</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="52"/>
        <source>Select application language:</source>
        <translation>Seleziona la lingua dell&apos;applicazione:</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="55"/>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;System Language&gt;</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="174"/>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="174"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Riavviare questa applicazione per rendere effettiva la modifica della lingua.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="45"/>
        <source>New Game</source>
        <translation>Nuovo Gioco</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="58"/>
        <location filename="../src/window.cpp" line="279"/>
        <source>Low</source>
        <translation>Basso</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="58"/>
        <location filename="../src/window.cpp" line="280"/>
        <source>Medium</source>
        <translation>Medio</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="58"/>
        <location filename="../src/window.cpp" line="281"/>
        <source>High</source>
        <translation>Alto</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="58"/>
        <location filename="../src/window.cpp" line="282"/>
        <source>Very High</source>
        <translation>Molto Alto</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="93"/>
        <location filename="../src/window.cpp" line="293"/>
        <source>Language:</source>
        <translation>Lingua:</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="95"/>
        <location filename="../src/window.cpp" line="295"/>
        <source>Word Length:</source>
        <translation>Lunghezza della parola:</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="94"/>
        <location filename="../src/window.cpp" line="294"/>
        <source>Amount of Words:</source>
        <translation>Quantità di parole:</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/new_game_dialog.cpp" line="144"/>
        <location filename="../src/window.cpp" line="295"/>
        <source>%n letter(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>RingsPattern</name>
    <message>
        <location filename="../src/pattern.h" line="195"/>
        <source>Rings</source>
        <translation>Anelli</translation>
    </message>
</context>
<context>
    <name>ScoreBoard</name>
    <message>
        <location filename="../src/score_board.cpp" line="33"/>
        <source>Scores</source>
        <translation>Punteggi</translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="37"/>
        <source>Score</source>
        <translation>Punteggio</translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="37"/>
        <source>Time</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="37"/>
        <source>Words</source>
        <translation>Parole</translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="37"/>
        <source>Length</source>
        <translation>Lunghezza</translation>
    </message>
</context>
<context>
    <name>StairsPattern</name>
    <message>
        <location filename="../src/pattern.h" line="216"/>
        <source>Stairs</source>
        <translation>Scale</translation>
    </message>
</context>
<context>
    <name>TwistyPattern</name>
    <message>
        <location filename="../src/pattern.h" line="233"/>
        <source>Twisty</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WavePattern</name>
    <message>
        <location filename="../src/pattern.h" line="256"/>
        <source>Wave</source>
        <translation>Onda</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/window.cpp" line="70"/>
        <location filename="../src/window.cpp" line="87"/>
        <source>Success</source>
        <translation>Successo</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="99"/>
        <source>Loading</source>
        <translation>Caricamento</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="99"/>
        <source>Paused</source>
        <translation>In pausa</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="123"/>
        <source>Definitions</source>
        <translation>Definizioni</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="129"/>
        <source>Hint</source>
        <translation>Suggerimento</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="160"/>
        <source>&amp;Game</source>
        <translation>&amp;Gioco</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="161"/>
        <source>&amp;New</source>
        <translation>&amp;Nuovo</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="162"/>
        <source>&amp;Choose...</source>
        <translation>&amp;Scegli...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="171"/>
        <source>&amp;Details</source>
        <translation>&amp;Dettagli</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="164"/>
        <location filename="../src/window.cpp" line="339"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pausa</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="164"/>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="166"/>
        <source>&amp;Hint</source>
        <translation>&amp;Suggerimento</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="166"/>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="169"/>
        <source>D&amp;efinitions</source>
        <translation>D&amp;efinizioni</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="169"/>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="172"/>
        <source>&amp;Scores</source>
        <translation>&amp;Punteggio</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="174"/>
        <source>&amp;Quit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="177"/>
        <source>&amp;Settings</source>
        <translation>&amp;Impostazioni</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="178"/>
        <source>Application &amp;Language...</source>
        <translation>Applicazione &amp;Lingua...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="180"/>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="181"/>
        <source>&amp;About</source>
        <translation>&amp;Informazioni su</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="183"/>
        <source>About &amp;Qt</source>
        <translation>Informazioni su &amp;Qt</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="218"/>
        <source>Choose Game</source>
        <translation>Scegli Gioco</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="218"/>
        <location filename="../src/window.cpp" line="296"/>
        <source>Game Number:</source>
        <translation>Numero Gioco:</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="222"/>
        <source>Sorry</source>
        <translation>Mi dispiace</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="222"/>
        <source>Unable to start requested game.</source>
        <translation>Impossibile avviare il gioco richiesto.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="262"/>
        <source>About</source>
        <translation>Informazioni su</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="38"/>
        <location filename="../src/window.cpp" line="263"/>
        <source>Connectagram</source>
        <translation>Connectagram</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="264"/>
        <source>A word unscrambling game</source>
        <translation>Un gioco di riordino delle parole</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="265"/>
        <source>Copyright &amp;copy; 2009-%1 by Graeme Gott</source>
        <translation>Copyright &amp;copy; 2009-%1 by Graeme Gott</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="266"/>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Rilasciato sotto licenza &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; </translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="267"/>
        <source>Definitions are from &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</source>
        <translation>Le definizioni provengono da &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="290"/>
        <source>Details</source>
        <translation>Dettagli</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="292"/>
        <source>Pattern:</source>
        <translation>Percorso:</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="339"/>
        <source>&amp;Resume</source>
        <translation>&amp;Ripristina</translation>
    </message>
</context>
</TS>

==> connectagram_1.3.3.orig.tar.gz: connectagram-1.3.3/translations/connectagram_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>ChainPattern</name>
    <message>
        <source>Chain</source>
        <translation>Catena</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>Loading</source>
        <translation>Caricamento in corso</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pausa</translation>
    </message>
</context>
<context>
    <name>FencePattern</name>
    <message>
        <source>Fence</source>
        <translation>Recinto</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Seleziona la lingua dell&apos;applicazione:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;System Language&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Riavviare questa applicazione per rendere effettiva la modifica della lingua.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Nuovo Gioco</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Basso</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Medio</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Alto</translation>
    </message>
    <message>
        <source>Very High</source>
        <translation>Molto Alto</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Lingua:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Lunghezza della parola:</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Quantità di parole:</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>RingsPattern</name>
    <message>
        <source>Rings</source>
        <translation>Anelli</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>High Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Punteggio</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <source>Words</source>
        <translation>Parole</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Lunghezza</translation>
    </message>
    <message>
        <source>#%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StairsPattern</name>
    <message>
        <source>Stairs</source>
        <translation>Scale</translation>
    </message>
</context>
<context>
    <name>TwistyPattern</name>
    <message>
        <source>Twisty</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WavePattern</name>
    <message>
        <source>Wave</source>
        <translation>Onda</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Success</source>
        <translation>Successo</translation>
    </message>
    <message>
        <source>Loading</source>
        <translation>Caricamento</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>In pausa</translation>
    </message>
    <message>
        <source>Definitions</source>
        <translation>Definizioni</translation>
    </message>
    <message>
        <source>Hint</source>
        <translation>Suggerimento</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Gioco</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nuovo</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Scegli...</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Dettagli</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pausa</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Suggerimento</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>D&amp;efinitions</source>
        <translation>D&amp;efinizioni</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Impostazioni</translation>
    </message>
    <message>
        <source>&amp;Dark Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Applicazione &amp;Lingua...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Informazioni su</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Informazioni su &amp;Qt</translation>
    </message>
    <message>
        <source>Choose Game</source>
        <translation>Scegli Gioco</translation>
    </message>
    <message>
        <source>Game Number:</source>
        <translation>Numero Gioco:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Mi dispiace</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Impossibile avviare il gioco richiesto.</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Informazioni su</translation>
    </message>
    <message>
        <source>Connectagram</source>
        <translation>Connectagram</translation>
    </message>
    <message>
        <source>A word unscrambling game</source>
        <translation>Un gioco di riordino delle parole</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 by Graeme Gott</source>
        <translation>Copyright &amp;copy; 2009-%1 by Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Rilasciato sotto licenza &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; </translation>
    </message>
    <message>
        <source>Definitions are from &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</source>
        <translation>Le definizioni provengono da &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Dettagli</translation>
    </message>
    <message>
        <source>Pattern:</source>
        <translation>Percorso:</translation>
    </message>
</context>
</TS>
